@@ -1,6 +1,7 @@
 import torch
 import numpy as np
 import pandas as pd
+from copy import deepcopy
 from PIL import Image
 from pathlib import Path
 from warnings import warn
@@ -223,7 +224,7 @@ class Callback:
             for ax, metrics, scale in zip(self._graph_axes, self._graph_metrics, self._graph_scales):
                 ax.set_xlabel("Epoch")
                 for metric in metrics:
-                    self._plot(ax, [], [], scale, metric)
+                    self._plot(ax, self.logs["epoch"], self.logs[metric], scale, metric)
                 ax.legend()                        
             self._graph_nb = display(self._graph_fig, display_id=True)
         else:
@@ -280,8 +281,15 @@ class Callback:
     def _save_ckpt(self):
         ckpt_path = self.outdir / "checkpoint"
         ckpt_path.mkdir(parents=True, exist_ok=True)
-
-        torch.save(self, ckpt_path / f'epoch_{self.epoch}.pth')
+        
+        callback = deepcopy(self)
+        callback._report_nb = None
+        callback._graph_nb = None
+        callback._image_nb = None
+        callback._graph_fig = None
+        callback._graph_axes = None
+        torch.save(callback, ckpt_path / f'epoch_{self.epoch}.pth')
+        del(callback)
 
     def _check_value(self, model, model_config, optimizer_config, metadata, max_epoch):
         self.max_epoch = max_epoch if max_epoch is not None else np.inf
